# ewoks3dxrd

**ewoks3dxrd** is a project to process 3DXRD data using [ImageD11](https://github.com/FABLE-3DXRD/ImageD11). It provides an [Orange3](https://github.com/biolab/orange3) graphical user interface to process data with ImageD11 under the form of computational data pipelines composed of several tasks, also called workflows. It can also run the workflows in batch via headless processing by using [Ewoks](https://ewoks.esrf.fr/en/latest/).

## Quick start

```code
pip install ewoks3dxrd[full]
```

Then, launch the Orange canvas with

```bash
ewoks-canvas
```

Open the tutorial workflow or drag widgets from the left panel to the canvas to make a workflow

## Documentation

https://ewoks3dxrd.readthedocs.io/
